]> mj.ucw.cz Git - ursary.git/commitdiff
Group 6 is Zoom, group 7 is everything else regardless of host
authorMartin Mares <mj@ucw.cz>
Wed, 6 May 2020 20:33:56 +0000 (22:33 +0200)
committerMartin Mares <mj@ucw.cz>
Wed, 6 May 2020 20:34:47 +0000 (22:34 +0200)
ursaryd.c

index 29b434002772d4c43df7c362d9d08e42e9fad382..9d400233cc314c8daca05ce0d699775a781a7687 100644 (file)
--- a/ursaryd.c
+++ b/ursaryd.c
  *     1       sink BT         mute            switch to BT
  *     2       ceil brightness mic non-mute    ceiling lights on
  *     3       desk brightness -               desk lights on
- *     4       MPD             mute            MPD play/pause
+ *     4       Albireo MPD     mute            MPD play/pause
  *     5       Albireo MPV     mute            MPD stop
*     6       Albireo other   mute            MPD prev
*     7       other machines  mute            MPD next
  *
  *     center  -
  *     slider  light color temperature
@@ -121,7 +121,7 @@ struct client_map {
 static struct client_map client_map[] = {
   { 4, "Music Player Daemon",  "albireo",      },
   { 5, "mpv",                  "albireo",      },
-  { 6, NULL,                   "albireo",      },
+  { 6, "ZOOM VoiceEngine",     "albireo",      },
   { 7, NULL,                   NULL,           },
 };
@@
  *     5       Albireo MPV     mute            MPD stop
- *     6       Albireo other   mute            MPD prev
- *     7       other machines  mute            MPD next
+ *     6       Albireo Zoom    mute            MPD prev
+ *     7       eveyrhing else  mute            MPD next
  *
  *     center  -